@@ -96,6 +96,7 @@ sub init_test
       or die "Failed to create $ENV{HOME}: $!";
 
   delete $ENV{V}; # In case we're being released with a manual version
+  delete $ENV{$_} for grep /^GIT_/i, keys %ENV;
 
   # Create the test repo:
   $git_dir = $base_dir->child('repo');
@@ -157,7 +158,18 @@ sub skip_unless_git_version
 sub slurp_text_file
 {
   my ($filename) = @_;
-  return path( $zilla->tempdir )->child( $filename )->slurp_utf8;
+
+  return scalar do {
+    local $/;
+    # Don't use Path::Tiny's slurp_utf8 because it doesn't do
+    # CRLF translation on Windows.
+    if (open my $fh, '<:utf8', path( $zilla->tempdir )->child( $filename )) {
+      <$fh>;
+    } else {
+      diag("Unable to open $filename: $!");
+      undef;
+    }
+  };
 } # end slurp_text_file
 
 #---------------------------------------------------------------------
